# B-FADE: Bayesian FAtigue moDel Estimator

The package implements Maximum a Posteriori Estimation (MAP) to accomplish the estimation of fatigue models' parameters. Currently the package is designed to identify the El Haddad (EH) curve given a fatigue & defectivity characterisation dataset. Other curves are foreseen in future developments.

## Features

- Maximum a Posteriori Estimation and computation of the predictive posterior.
- Monte Carlo Estimation of the prediction interval for the considered curve.
- Data pre-processing & visualisation.

## Quick Setup

B-FADE is available at [PyPI](https://pypi.org/project/b-fade/), so it can be installed using common package managers, such as `pip` or `conda`:

```
pip install --user b-fade
```

```
conda install b-fade
```

For further instructions, please take a look at the documentation.

## Documentation

Please refer to [ReadTheDocs](https://b-fade.readthedocs.io/en/latest/) for detailed instructions about installing, utilising B-FADE and working examples.